#[repr(u8)]pub enum EvtgAoi0Bft01Pt0Dc {
DC_0 = 0,
DC_1 = 1,
DC_2 = 2,
DC_3 = 3,
}Variants
DC_0 = 0
Force the D input in this product term to a logical zero
DC_1 = 1
Pass the D input in this product term
DC_2 = 2
Complement the D input in this product term
DC_3 = 3
Force the D input in this product term to a logical one
Implementations