#[repr(u8)]pub enum EvtgAoi0Bft23Pt3Dc {
PT3_DC0 = 0,
PT3_DC1 = 1,
PT3_DC2 = 2,
PT3_DC3 = 3,
}Variants
PT3_DC0 = 0
Force the D input in this product term to a logical zero
PT3_DC1 = 1
Pass the D input in this product term
PT3_DC2 = 2
Complement the D input in this product term
PT3_DC3 = 3
Force the D input in this product term to a logical one
Implementations