#[repr(u8)]pub enum EvtgAoi1Bft01Pt0Cc {
PT0_CC0 = 0,
PT0_CC1 = 1,
PT0_CC2 = 2,
PT0_CC3 = 3,
}Variants
PT0_CC0 = 0
Force the C input in this product term to a logical zero
PT0_CC1 = 1
Pass the C input in this product term
PT0_CC2 = 2
Complement the C input in this product term
PT0_CC3 = 3
Force the C input in this product term to a logical one
Implementations