#[repr(u8)]pub enum EvtgAoi1Bft01Pt0Dc {
PT0_DC0 = 0,
PT0_DC1 = 1,
PT0_DC2 = 2,
PT0_DC3 = 3,
}Variants
PT0_DC0 = 0
Force the D input in this product term to a logical zero
PT0_DC1 = 1
Pass the D input in this product term
PT0_DC2 = 2
Complement the D input in this product term
PT0_DC3 = 3
Force the D input in this product term to a logical one
Implementations