#[repr(u8)]pub enum EvtgAoi1Bft23Pt2Bc {
PT2_BC0 = 0,
PT2_BC1 = 1,
PT2_BC2 = 2,
PT2_BC3 = 3,
}Variants
PT2_BC0 = 0
Force the B input in this product term to a logical zero
PT2_BC1 = 1
Pass the B input in this product term
PT2_BC2 = 2
Complement the B input in this product term
PT2_BC3 = 3
Force the B input in this product term to a logical one
Implementations