#[repr(u8)]pub enum EvtgAoi1Bft23Pt2Cc {
PT2_CC0 = 0,
PT2_CC1 = 1,
PT2_CC2 = 2,
PT2_CC3 = 3,
}Variants
PT2_CC0 = 0
Force the C input in this product term to a logical zero
PT2_CC1 = 1
Pass the C input in this product term
PT2_CC2 = 2
Complement the C input in this product term
PT2_CC3 = 3
Force the C input in this product term to a logical one
Implementations