#[repr(u8)]pub enum EvtgAoi1Bft23Pt2Dc {
PT2_DC0 = 0,
PT2_DC1 = 1,
PT2_DC2 = 2,
PT2_DC3 = 3,
}Variants
PT2_DC0 = 0
Force the D input in this product term to a logical zero
PT2_DC1 = 1
Pass the D input in this product term
PT2_DC2 = 2
Complement the D input in this product term
PT2_DC3 = 3
Force the D input in this product term to a logical one
Implementations