#[repr(u8)]pub enum EvtgAoi1Bft23Pt3Ac {
PT3_AC0 = 0,
PT3_AC1 = 1,
PT3_AC2 = 2,
PT3_AC3 = 3,
}Variants
PT3_AC0 = 0
Force the A input in this product term to a logical zero
PT3_AC1 = 1
Pass the A input in this product term
PT3_AC2 = 2
Complement the A input in this product term
PT3_AC3 = 3
Force the A input in this product term to a logical one
Implementations