#[repr(u8)]pub enum EvtgAoi1Bft23Pt3Bc {
PT3_BC0 = 0,
PT3_BC1 = 1,
PT3_BC2 = 2,
PT3_BC3 = 3,
}Variants
PT3_BC0 = 0
Force the B input in this product term to a logical zero
PT3_BC1 = 1
Pass the B input in this product term
PT3_BC2 = 2
Complement the B input in this product term
PT3_BC3 = 3
Force the B input in this product term to a logical one
Implementations