#[repr(u8)]pub enum EvtgAoi1Bft23Pt3Cc {
PT3_CC0 = 0,
PT3_CC1 = 1,
PT3_CC2 = 2,
PT3_CC3 = 3,
}Variants
PT3_CC0 = 0
Force the C input in this product term to a logical zero
PT3_CC1 = 1
Pass the C input in this product term
PT3_CC2 = 2
Complement the C input in this product term
PT3_CC3 = 3
Force the C input in this product term to a logical one
Implementations